@@ -71,6 +71,12 @@ val set_pitch : t -> float -> unit
 
 (** {2 Sound manipulation} *)
 
+(** Put samples. Data is interleaved with given number of channels. *)
+val put_samples_ba :
+  t ->
+  (float, Bigarray.float32_elt, Bigarray.c_layout) Bigarray.Array1.t ->
+  unit
+
 (** Put samples (in a non-interleaved format) with given offset in array and
     number of samples. *)
 val put_samples_ni : t -> float array array -> int -> int -> unit
@@ -78,6 +84,10 @@ val put_samples_ni : t -> float array array -> int -> int -> unit
 (** Number of available output samples. *)
 val get_available_samples : t -> int
 
+(** Retreive samples. *)
+val get_samples_ba :
+  t -> (float, Bigarray.float32_elt, Bigarray.c_layout) Bigarray.Array1.t -> int
+
 (** Retreive samples (in a non-interleaved format). *)
 val get_samples_ni : t -> float array array -> int -> int -> int
 
@@ -96,6 +106,12 @@ module BPM : sig
       samplerate. *)
   val make : int -> int -> t
 
+  (** Put samples in the detector. *)
+  val put_samples_ba :
+    t ->
+    (float, Bigarray.float32_elt, Bigarray.c_layout) Bigarray.Array1.t ->
+    unit
+
   (** Put samples in the detector. *)
   val put_samples_ni : t -> float array array -> int -> int -> unit
 
